pack

package module
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2019 License: Apache-2.0 Imports: 33 Imported by: 0

README

pack - Buildpack CLI Travis Build Status

pack is a CLI implementation of the Platform Interface Specification for Cloud Native Buildpacks.

pack makes it easy for...

  • Application developers to use Cloud Native Buildpacks to convert code into runnable images.
  • Buildpack authors to develop and package buildpacks for distribution.

Usage

Contributing

For information on how to contribute to this project including its development process see CONTRIBUTING.md.

Resources

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BuildOptions added in v0.2.0

type BuildOptions struct {
	Image             string              // required
	Builder           string              // required
	AppPath           string              // defaults to current working directory
	RunImage          string              // defaults to the best mirror from the builder metadata or AdditionalMirrors
	AdditionalMirrors map[string][]string // only considered if RunImage is not provided
	Env               map[string]string
	Publish           bool
	NoPull            bool
	ClearCache        bool
	Buildpacks        []string
	ProxyConfig       *ProxyConfig // defaults to  environment proxy vars
}

type BuilderInfo added in v0.1.0

type BuilderInfo struct {
	Description      string
	Stack            string
	RunImage         string
	RunImageMirrors  []string
	Buildpacks       []builder.BuildpackMetadata
	Groups           []builder.GroupMetadata
	LifecycleVersion string
}

type BuildpackFetcher added in v0.2.0

type BuildpackFetcher interface {
	FetchBuildpack(uri string) (buildpack.Buildpack, error)
}

type BuildpackInfo added in v0.1.0

type BuildpackInfo struct {
	ID      string
	Version string
	Latest  bool
}

type Client added in v0.1.0

type Client struct {
	// contains filtered or unexported fields
}

func NewClient added in v0.1.0

func NewClient(opts ...ClientOption) (*Client, error)

func (*Client) Build added in v0.2.0

func (c *Client) Build(ctx context.Context, opts BuildOptions) error

func (*Client) CreateBuilder added in v0.2.0

func (c *Client) CreateBuilder(ctx context.Context, opts CreateBuilderOptions) error

func (*Client) InspectBuilder added in v0.1.0

func (c *Client) InspectBuilder(name string, daemon bool) (*BuilderInfo, error)

func (*Client) Rebase added in v0.2.0

func (c *Client) Rebase(ctx context.Context, opts RebaseOptions) error

func (*Client) Run added in v0.2.0

func (c *Client) Run(ctx context.Context, opts RunOptions) error

type ClientOption added in v0.3.0

type ClientOption func(c *Client)

func WithDockerClient added in v0.3.0

func WithDockerClient(docker *dockerClient.Client) ClientOption

WithDockerClient supply your own docker client.

func WithLogger added in v0.3.0

func WithLogger(l logging.Logger) ClientOption

WithLogger supply your own logger.

type CreateBuilderOptions added in v0.2.0

type CreateBuilderOptions struct {
	BuilderName   string
	BuilderConfig builder.Config
	Publish       bool
	NoPull        bool
}

type Downloader added in v0.2.0

type Downloader struct {
	// contains filtered or unexported fields
}

func NewDownloader added in v0.2.0

func NewDownloader(logger logging.Logger, baseCacheDir string) *Downloader

func (*Downloader) Download added in v0.2.0

func (d *Downloader) Download(pathOrUri string) (string, error)

type ImageFetcher added in v0.1.0

type ImageFetcher interface {
	Fetch(ctx context.Context, name string, daemon, pull bool) (imgutil.Image, error)
}

type Lifecycle added in v0.2.0

type Lifecycle interface {
	Execute(ctx context.Context, opts build.LifecycleOptions) error
}

type LifecycleFetcher added in v0.2.0

type LifecycleFetcher interface {
	Fetch(version *semver.Version, uri string) (lifecycle.Metadata, error)
}

type ProxyConfig added in v0.2.0

type ProxyConfig struct {
	HTTPProxy  string
	HTTPSProxy string
	NoProxy    string
}

type RebaseOptions added in v0.2.0

type RebaseOptions struct {
	RepoName          string
	Publish           bool
	SkipPull          bool
	RunImage          string
	AdditionalMirrors map[string][]string
}

type RunOptions added in v0.2.0

type RunOptions struct {
	AppPath    string // defaults to current working directory
	Builder    string // defaults to default builder on the client config
	RunImage   string // defaults to the best mirror from the builder image
	Env        map[string]string
	NoPull     bool
	ClearCache bool
	Buildpacks []string
	Ports      []string
}

Directories

Path Synopsis
cmd
pack command
mocks
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
internal
logging
Package logging implements the logger for the pack CLI.
Package logging implements the logger for the pack CLI.
mocks
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package logging defines the minimal interface that loggers must support to be used by pack.
Package logging defines the minimal interface that loggers must support to be used by pack.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.

Jump to