testmocks

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 6, 2019 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package testmocks is a generated GoMock package.

Package testmocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockBuildpack

type MockBuildpack struct {
	// contains filtered or unexported fields
}

MockBuildpack is a mock of Buildpack interface

func NewMockBuildpack

func NewMockBuildpack(ctrl *gomock.Controller) *MockBuildpack

NewMockBuildpack creates a new mock instance

func (*MockBuildpack) Descriptor

func (m *MockBuildpack) Descriptor() builder.BuildpackDescriptor

Descriptor mocks base method

func (*MockBuildpack) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockBuildpack) Open

func (m *MockBuildpack) Open() (io.ReadCloser, error)

Open mocks base method

type MockBuildpackMockRecorder

type MockBuildpackMockRecorder struct {
	// contains filtered or unexported fields
}

MockBuildpackMockRecorder is the mock recorder for MockBuildpack

func (*MockBuildpackMockRecorder) Descriptor

func (mr *MockBuildpackMockRecorder) Descriptor() *gomock.Call

Descriptor indicates an expected call of Descriptor

func (*MockBuildpackMockRecorder) Open

Open indicates an expected call of Open

type MockLifecycle

type MockLifecycle struct {
	// contains filtered or unexported fields
}

MockLifecycle is a mock of Lifecycle interface

func NewMockLifecycle

func NewMockLifecycle(ctrl *gomock.Controller) *MockLifecycle

NewMockLifecycle creates a new mock instance

func (*MockLifecycle) Descriptor

func (m *MockLifecycle) Descriptor() builder.LifecycleDescriptor

Descriptor mocks base method

func (*MockLifecycle) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockLifecycle) Open

func (m *MockLifecycle) Open() (io.ReadCloser, error)

Open mocks base method

type MockLifecycleMockRecorder

type MockLifecycleMockRecorder struct {
	// contains filtered or unexported fields
}

MockLifecycleMockRecorder is the mock recorder for MockLifecycle

func (*MockLifecycleMockRecorder) Descriptor

func (mr *MockLifecycleMockRecorder) Descriptor() *gomock.Call

Descriptor indicates an expected call of Descriptor

func (*MockLifecycleMockRecorder) Open

Open indicates an expected call of Open

Jump to