commands

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2019 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddHelpFlag

func AddHelpFlag(cmd *cobra.Command, commandName string)

TODO: Check if most recent cobra version fixed bug in help strings. It was not always capitalizing the first letter in the help string. If it's fixed, we can remove this.

func Build

func Build(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command

func CreateBuilder

func CreateBuilder(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command

func InspectBuilder

func InspectBuilder(logger *logging.Logger, cfg *config.Config, inspector BuilderInspector) *cobra.Command

func IsSoftError

func IsSoftError(err error) bool

func Rebase

func Rebase(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command

func Run

func Run(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command

func SetDefaultBuilder

func SetDefaultBuilder(logger *logging.Logger) *cobra.Command

func SetRunImagesMirrors

func SetRunImagesMirrors(logger *logging.Logger) *cobra.Command

func Version

func Version(logger *logging.Logger, version string) *cobra.Command

Types

type BuilderInspector

type BuilderInspector interface {
	InspectBuilder(string, bool) (*pack.BuilderInfo, error)
}

type SoftError

type SoftError struct {
}

func MakeSoftError

func MakeSoftError() SoftError

func (SoftError) Error

func (se SoftError) Error() string

Directories

Path Synopsis
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.

Jump to