mocks

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2019 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockBuildRunner added in v0.1.0

type MockBuildRunner struct {
	// contains filtered or unexported fields
}

MockBuildRunner is a mock of BuildRunner interface

func NewMockBuildRunner added in v0.1.0

func NewMockBuildRunner(ctrl *gomock.Controller) *MockBuildRunner

NewMockBuildRunner creates a new mock instance

func (*MockBuildRunner) EXPECT added in v0.1.0

EXPECT returns an object that allows the caller to indicate expected use

func (*MockBuildRunner) Run added in v0.1.0

func (m *MockBuildRunner) Run(arg0 context.Context) error

Run mocks base method

type MockBuildRunnerMockRecorder added in v0.1.0

type MockBuildRunnerMockRecorder struct {
	// contains filtered or unexported fields
}

MockBuildRunnerMockRecorder is the mock recorder for MockBuildRunner

func (*MockBuildRunnerMockRecorder) Run added in v0.1.0

func (mr *MockBuildRunnerMockRecorder) Run(arg0 interface{}) *gomock.Call

Run indicates an expected call of Run

type MockCache added in v0.1.0

type MockCache struct {
	// contains filtered or unexported fields
}

MockCache is a mock of Cache interface

func NewMockCache added in v0.1.0

func NewMockCache(ctrl *gomock.Controller) *MockCache

NewMockCache creates a new mock instance

func (*MockCache) Clear added in v0.1.0

func (m *MockCache) Clear(arg0 context.Context) error

Clear mocks base method

func (*MockCache) EXPECT added in v0.1.0

func (m *MockCache) EXPECT() *MockCacheMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockCache) Image added in v0.1.0

func (m *MockCache) Image() string

Image mocks base method

type MockCacheMockRecorder added in v0.1.0

type MockCacheMockRecorder struct {
	// contains filtered or unexported fields
}

MockCacheMockRecorder is the mock recorder for MockCache

func (*MockCacheMockRecorder) Clear added in v0.1.0

func (mr *MockCacheMockRecorder) Clear(arg0 interface{}) *gomock.Call

Clear indicates an expected call of Clear

func (*MockCacheMockRecorder) Image added in v0.1.0

func (mr *MockCacheMockRecorder) Image() *gomock.Call

Image indicates an expected call of Image

type MockDocker

type MockDocker struct {
	// contains filtered or unexported fields
}

MockDocker is a mock of Docker interface

func NewMockDocker

func NewMockDocker(ctrl *gomock.Controller) *MockDocker

NewMockDocker creates a new mock instance

func (*MockDocker) ContainerCreate

ContainerCreate mocks base method

func (*MockDocker) ContainerList added in v0.1.0

func (m *MockDocker) ContainerList(arg0 context.Context, arg1 types.ContainerListOptions) ([]types.Container, error)

ContainerList mocks base method

func (*MockDocker) ContainerRemove

func (m *MockDocker) ContainerRemove(arg0 context.Context, arg1 string, arg2 types.ContainerRemoveOptions) error

ContainerRemove mocks base method

func (*MockDocker) CopyFromContainer

func (m *MockDocker) CopyFromContainer(arg0 context.Context, arg1, arg2 string) (io.ReadCloser, types.ContainerPathStat, error)

CopyFromContainer mocks base method

func (*MockDocker) CopyToContainer

func (m *MockDocker) CopyToContainer(arg0 context.Context, arg1, arg2 string, arg3 io.Reader, arg4 types.CopyToContainerOptions) error

CopyToContainer mocks base method

func (*MockDocker) EXPECT

func (m *MockDocker) EXPECT() *MockDockerMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockDocker) ImageBuild

ImageBuild mocks base method

func (*MockDocker) ImageInspectWithRaw

func (m *MockDocker) ImageInspectWithRaw(arg0 context.Context, arg1 string) (types.ImageInspect, []byte, error)

ImageInspectWithRaw mocks base method

func (*MockDocker) ImageRemove added in v0.1.0

ImageRemove mocks base method

func (*MockDocker) PullImage

func (m *MockDocker) PullImage(arg0 context.Context, arg1 string, arg2 io.Writer) error

PullImage mocks base method

func (*MockDocker) RunContainer

func (m *MockDocker) RunContainer(arg0 context.Context, arg1 string, arg2, arg3 io.Writer) error

RunContainer mocks base method

func (*MockDocker) VolumeRemove

func (m *MockDocker) VolumeRemove(arg0 context.Context, arg1 string, arg2 bool) error

VolumeRemove mocks base method

type MockDockerMockRecorder

type MockDockerMockRecorder struct {
	// contains filtered or unexported fields
}

MockDockerMockRecorder is the mock recorder for MockDocker

func (*MockDockerMockRecorder) ContainerCreate

func (mr *MockDockerMockRecorder) ContainerCreate(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call

ContainerCreate indicates an expected call of ContainerCreate

func (*MockDockerMockRecorder) ContainerList added in v0.1.0

func (mr *MockDockerMockRecorder) ContainerList(arg0, arg1 interface{}) *gomock.Call

ContainerList indicates an expected call of ContainerList

func (*MockDockerMockRecorder) ContainerRemove

func (mr *MockDockerMockRecorder) ContainerRemove(arg0, arg1, arg2 interface{}) *gomock.Call

ContainerRemove indicates an expected call of ContainerRemove

func (*MockDockerMockRecorder) CopyFromContainer

func (mr *MockDockerMockRecorder) CopyFromContainer(arg0, arg1, arg2 interface{}) *gomock.Call

CopyFromContainer indicates an expected call of CopyFromContainer

func (*MockDockerMockRecorder) CopyToContainer

func (mr *MockDockerMockRecorder) CopyToContainer(arg0, arg1, arg2, arg3, arg4 interface{}) *gomock.Call

CopyToContainer indicates an expected call of CopyToContainer

func (*MockDockerMockRecorder) ImageBuild

func (mr *MockDockerMockRecorder) ImageBuild(arg0, arg1, arg2 interface{}) *gomock.Call

ImageBuild indicates an expected call of ImageBuild

func (*MockDockerMockRecorder) ImageInspectWithRaw

func (mr *MockDockerMockRecorder) ImageInspectWithRaw(arg0, arg1 interface{}) *gomock.Call

ImageInspectWithRaw indicates an expected call of ImageInspectWithRaw

func (*MockDockerMockRecorder) ImageRemove added in v0.1.0

func (mr *MockDockerMockRecorder) ImageRemove(arg0, arg1, arg2 interface{}) *gomock.Call

ImageRemove indicates an expected call of ImageRemove

func (*MockDockerMockRecorder) PullImage

func (mr *MockDockerMockRecorder) PullImage(arg0, arg1, arg2 interface{}) *gomock.Call

PullImage indicates an expected call of PullImage

func (*MockDockerMockRecorder) RunContainer

func (mr *MockDockerMockRecorder) RunContainer(arg0, arg1, arg2, arg3 interface{}) *gomock.Call

RunContainer indicates an expected call of RunContainer

func (*MockDockerMockRecorder) VolumeRemove

func (mr *MockDockerMockRecorder) VolumeRemove(arg0, arg1, arg2 interface{}) *gomock.Call

VolumeRemove indicates an expected call of VolumeRemove

type MockFetcher added in v0.1.0

type MockFetcher struct {
	// contains filtered or unexported fields
}

MockFetcher is a mock of Fetcher interface

func NewMockFetcher added in v0.1.0

func NewMockFetcher(ctrl *gomock.Controller) *MockFetcher

NewMockFetcher creates a new mock instance

func (*MockFetcher) EXPECT added in v0.1.0

func (m *MockFetcher) EXPECT() *MockFetcherMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockFetcher) FetchLocalImage added in v0.1.0

func (m *MockFetcher) FetchLocalImage(arg0 string) (image.Image, error)

FetchLocalImage mocks base method

func (*MockFetcher) FetchRemoteImage added in v0.1.0

func (m *MockFetcher) FetchRemoteImage(arg0 string) (image.Image, error)

FetchRemoteImage mocks base method

func (*MockFetcher) FetchUpdatedLocalImage added in v0.1.0

func (m *MockFetcher) FetchUpdatedLocalImage(arg0 context.Context, arg1 string, arg2 io.Writer) (image.Image, error)

FetchUpdatedLocalImage mocks base method

type MockFetcherMockRecorder added in v0.1.0

type MockFetcherMockRecorder struct {
	// contains filtered or unexported fields
}

MockFetcherMockRecorder is the mock recorder for MockFetcher

func (*MockFetcherMockRecorder) FetchLocalImage added in v0.1.0

func (mr *MockFetcherMockRecorder) FetchLocalImage(arg0 interface{}) *gomock.Call

FetchLocalImage indicates an expected call of FetchLocalImage

func (*MockFetcherMockRecorder) FetchRemoteImage added in v0.1.0

func (mr *MockFetcherMockRecorder) FetchRemoteImage(arg0 interface{}) *gomock.Call

FetchRemoteImage indicates an expected call of FetchRemoteImage

func (*MockFetcherMockRecorder) FetchUpdatedLocalImage added in v0.1.0

func (mr *MockFetcherMockRecorder) FetchUpdatedLocalImage(arg0, arg1, arg2 interface{}) *gomock.Call

FetchUpdatedLocalImage indicates an expected call of FetchUpdatedLocalImage

type MockImage

type MockImage struct {
	// contains filtered or unexported fields
}

MockImage is a mock of Image interface

func NewMockImage

func NewMockImage(ctrl *gomock.Controller) *MockImage

NewMockImage creates a new mock instance

func (*MockImage) AddLayer added in v0.0.6

func (m *MockImage) AddLayer(arg0 string) error

AddLayer mocks base method

func (*MockImage) Delete added in v0.1.0

func (m *MockImage) Delete() error

Delete mocks base method

func (*MockImage) Digest

func (m *MockImage) Digest() (string, error)

Digest mocks base method

func (*MockImage) EXPECT

func (m *MockImage) EXPECT() *MockImageMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockImage) Env added in v0.0.8

func (m *MockImage) Env(arg0 string) (string, error)

Env mocks base method

func (*MockImage) Found added in v0.0.8

func (m *MockImage) Found() (bool, error)

Found mocks base method

func (*MockImage) GetLayer added in v0.1.0

func (m *MockImage) GetLayer(arg0 string) (io.ReadCloser, error)

GetLayer mocks base method

func (*MockImage) Label added in v0.0.6

func (m *MockImage) Label(arg0 string) (string, error)

Label mocks base method

func (*MockImage) Name added in v0.0.6

func (m *MockImage) Name() string

Name mocks base method

func (*MockImage) Rebase added in v0.0.6

func (m *MockImage) Rebase(arg0 string, arg1 image.Image) error

Rebase mocks base method

func (*MockImage) Rename added in v0.0.6

func (m *MockImage) Rename(arg0 string)

Rename mocks base method

func (*MockImage) ReuseLayer added in v0.0.6

func (m *MockImage) ReuseLayer(arg0 string) error

ReuseLayer mocks base method

func (*MockImage) Save added in v0.0.6

func (m *MockImage) Save() (string, error)

Save mocks base method

func (*MockImage) SetCmd added in v0.0.9

func (m *MockImage) SetCmd(arg0 ...string) error

SetCmd mocks base method

func (*MockImage) SetEntrypoint added in v0.0.9

func (m *MockImage) SetEntrypoint(arg0 ...string) error

SetEntrypoint mocks base method

func (*MockImage) SetEnv added in v0.0.8

func (m *MockImage) SetEnv(arg0, arg1 string) error

SetEnv mocks base method

func (*MockImage) SetLabel added in v0.0.6

func (m *MockImage) SetLabel(arg0, arg1 string) error

SetLabel mocks base method

func (*MockImage) TopLayer added in v0.0.6

func (m *MockImage) TopLayer() (string, error)

TopLayer mocks base method

type MockImageFactory added in v0.0.6

type MockImageFactory struct {
	// contains filtered or unexported fields
}

MockImageFactory is a mock of ImageFactory interface

func NewMockImageFactory added in v0.0.6

func NewMockImageFactory(ctrl *gomock.Controller) *MockImageFactory

NewMockImageFactory creates a new mock instance

func (*MockImageFactory) EXPECT added in v0.0.6

EXPECT returns an object that allows the caller to indicate expected use

func (*MockImageFactory) NewLocal added in v0.0.6

func (m *MockImageFactory) NewLocal(arg0 string) (image.Image, error)

NewLocal mocks base method

func (*MockImageFactory) NewRemote added in v0.0.6

func (m *MockImageFactory) NewRemote(arg0 string) (image.Image, error)

NewRemote mocks base method

type MockImageFactoryMockRecorder added in v0.0.6

type MockImageFactoryMockRecorder struct {
	// contains filtered or unexported fields
}

MockImageFactoryMockRecorder is the mock recorder for MockImageFactory

func (*MockImageFactoryMockRecorder) NewLocal added in v0.0.6

func (mr *MockImageFactoryMockRecorder) NewLocal(arg0 interface{}) *gomock.Call

NewLocal indicates an expected call of NewLocal

func (*MockImageFactoryMockRecorder) NewRemote added in v0.0.6

func (mr *MockImageFactoryMockRecorder) NewRemote(arg0 interface{}) *gomock.Call

NewRemote indicates an expected call of NewRemote

type MockImageMockRecorder

type MockImageMockRecorder struct {
	// contains filtered or unexported fields
}

MockImageMockRecorder is the mock recorder for MockImage

func (*MockImageMockRecorder) AddLayer added in v0.0.6

func (mr *MockImageMockRecorder) AddLayer(arg0 interface{}) *gomock.Call

AddLayer indicates an expected call of AddLayer

func (*MockImageMockRecorder) Delete added in v0.1.0

func (mr *MockImageMockRecorder) Delete() *gomock.Call

Delete indicates an expected call of Delete

func (*MockImageMockRecorder) Digest

func (mr *MockImageMockRecorder) Digest() *gomock.Call

Digest indicates an expected call of Digest

func (*MockImageMockRecorder) Env added in v0.0.8

func (mr *MockImageMockRecorder) Env(arg0 interface{}) *gomock.Call

Env indicates an expected call of Env

func (*MockImageMockRecorder) Found added in v0.0.8

func (mr *MockImageMockRecorder) Found() *gomock.Call

Found indicates an expected call of Found

func (*MockImageMockRecorder) GetLayer added in v0.1.0

func (mr *MockImageMockRecorder) GetLayer(arg0 interface{}) *gomock.Call

GetLayer indicates an expected call of GetLayer

func (*MockImageMockRecorder) Label added in v0.0.6

func (mr *MockImageMockRecorder) Label(arg0 interface{}) *gomock.Call

Label indicates an expected call of Label

func (*MockImageMockRecorder) Name added in v0.0.6

func (mr *MockImageMockRecorder) Name() *gomock.Call

Name indicates an expected call of Name

func (*MockImageMockRecorder) Rebase added in v0.0.6

func (mr *MockImageMockRecorder) Rebase(arg0, arg1 interface{}) *gomock.Call

Rebase indicates an expected call of Rebase

func (*MockImageMockRecorder) Rename added in v0.0.6

func (mr *MockImageMockRecorder) Rename(arg0 interface{}) *gomock.Call

Rename indicates an expected call of Rename

func (*MockImageMockRecorder) ReuseLayer added in v0.0.6

func (mr *MockImageMockRecorder) ReuseLayer(arg0 interface{}) *gomock.Call

ReuseLayer indicates an expected call of ReuseLayer

func (*MockImageMockRecorder) Save added in v0.0.6

func (mr *MockImageMockRecorder) Save() *gomock.Call

Save indicates an expected call of Save

func (*MockImageMockRecorder) SetCmd added in v0.0.9

func (mr *MockImageMockRecorder) SetCmd(arg0 ...interface{}) *gomock.Call

SetCmd indicates an expected call of SetCmd

func (*MockImageMockRecorder) SetEntrypoint added in v0.0.9

func (mr *MockImageMockRecorder) SetEntrypoint(arg0 ...interface{}) *gomock.Call

SetEntrypoint indicates an expected call of SetEntrypoint

func (*MockImageMockRecorder) SetEnv added in v0.0.8

func (mr *MockImageMockRecorder) SetEnv(arg0, arg1 interface{}) *gomock.Call

SetEnv indicates an expected call of SetEnv

func (*MockImageMockRecorder) SetLabel added in v0.0.6

func (mr *MockImageMockRecorder) SetLabel(arg0, arg1 interface{}) *gomock.Call

SetLabel indicates an expected call of SetLabel

func (*MockImageMockRecorder) TopLayer added in v0.0.6

func (mr *MockImageMockRecorder) TopLayer() *gomock.Call

TopLayer indicates an expected call of TopLayer

type MockTask added in v0.0.5

type MockTask struct {
	// contains filtered or unexported fields
}

MockTask is a mock of Task interface

func NewMockTask added in v0.0.5

func NewMockTask(ctrl *gomock.Controller) *MockTask

NewMockTask creates a new mock instance

func (*MockTask) EXPECT added in v0.0.5

func (m *MockTask) EXPECT() *MockTaskMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockTask) Run added in v0.0.5

func (m *MockTask) Run(arg0 context.Context) error

Run mocks base method

type MockTaskMockRecorder added in v0.0.5

type MockTaskMockRecorder struct {
	// contains filtered or unexported fields
}

MockTaskMockRecorder is the mock recorder for MockTask

func (*MockTaskMockRecorder) Run added in v0.0.5

func (mr *MockTaskMockRecorder) Run(arg0 interface{}) *gomock.Call

Run indicates an expected call of Run

type MockWritableStore added in v0.0.5

type MockWritableStore struct {
	// contains filtered or unexported fields
}

MockWritableStore is a mock of WritableStore interface

func NewMockWritableStore added in v0.0.5

func NewMockWritableStore(ctrl *gomock.Controller) *MockWritableStore

NewMockWritableStore creates a new mock instance

func (*MockWritableStore) EXPECT added in v0.0.5

EXPECT returns an object that allows the caller to indicate expected use

func (*MockWritableStore) Write added in v0.0.5

func (m *MockWritableStore) Write(arg0 v1.Image) error

Write mocks base method

type MockWritableStoreMockRecorder added in v0.0.5

type MockWritableStoreMockRecorder struct {
	// contains filtered or unexported fields
}

MockWritableStoreMockRecorder is the mock recorder for MockWritableStore

func (*MockWritableStoreMockRecorder) Write added in v0.0.5

func (mr *MockWritableStoreMockRecorder) Write(arg0 interface{}) *gomock.Call

Write indicates an expected call of Write

Jump to