package
Version:
v0.2.1
Opens a new window with list of versions in this module.
Published: May 30, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Metadata struct {
RunImage RunImageMetadata `toml:"run-image" json:"runImage"`
}
type RunImageMetadata struct {
Image string `toml:"image" json:"image"`
Mirrors []string `toml:"mirrors" json:"mirrors"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.