Documentation
¶
Index ¶
- type BuildOptions
- type BuilderInfo
- type BuildpackFetcher
- type BuildpackInfo
- type Client
- func (c *Client) Build(ctx context.Context, opts BuildOptions) error
- func (c *Client) CreateBuilder(ctx context.Context, opts CreateBuilderOptions) error
- func (c *Client) InspectBuilder(name string, daemon bool) (*BuilderInfo, error)
- func (c *Client) Rebase(ctx context.Context, opts RebaseOptions) error
- func (c *Client) Run(ctx context.Context, opts RunOptions) error
- type ClientOption
- type CreateBuilderOptions
- type Downloader
- type ImageFetcher
- type Lifecycle
- type LifecycleFetcher
- type ProxyConfig
- type RebaseOptions
- type RunOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildOptions ¶ added in v0.2.0
type BuildOptions struct {
Image string // required
Builder string // required
AppPath string // defaults to current working directory
RunImage string // defaults to the best mirror from the builder metadata or AdditionalMirrors
AdditionalMirrors map[string][]string // only considered if RunImage is not provided
Env map[string]string
Publish bool
NoPull bool
ClearCache bool
Buildpacks []string
ProxyConfig *ProxyConfig // defaults to environment proxy vars
}
type BuilderInfo ¶ added in v0.1.0
type BuilderInfo struct {
Description string
Stack string
RunImage string
RunImageMirrors []string
Buildpacks []builder.BuildpackMetadata
Groups []builder.GroupMetadata
LifecycleVersion string
}
type BuildpackFetcher ¶ added in v0.2.0
type BuildpackInfo ¶ added in v0.1.0
type Client ¶ added in v0.1.0
type Client struct {
// contains filtered or unexported fields
}
func NewClient ¶ added in v0.1.0
func NewClient(opts ...ClientOption) (*Client, error)
func (*Client) Build ¶ added in v0.2.0
func (c *Client) Build(ctx context.Context, opts BuildOptions) error
func (*Client) CreateBuilder ¶ added in v0.2.0
func (c *Client) CreateBuilder(ctx context.Context, opts CreateBuilderOptions) error
func (*Client) InspectBuilder ¶ added in v0.1.0
func (c *Client) InspectBuilder(name string, daemon bool) (*BuilderInfo, error)
type ClientOption ¶ added in v0.3.0
type ClientOption func(c *Client)
func WithDockerClient ¶ added in v0.3.0
func WithDockerClient(docker *dockerClient.Client) ClientOption
WithDockerClient supply your own docker client.
func WithLogger ¶ added in v0.3.0
func WithLogger(l logging.Logger) ClientOption
WithLogger supply your own logger.
type CreateBuilderOptions ¶ added in v0.2.0
type Downloader ¶ added in v0.2.0
type Downloader struct {
// contains filtered or unexported fields
}
func NewDownloader ¶ added in v0.2.0
func NewDownloader(logger logging.Logger, baseCacheDir string) *Downloader
type ImageFetcher ¶ added in v0.1.0
type Lifecycle ¶ added in v0.2.0
type Lifecycle interface {
Execute(ctx context.Context, opts build.LifecycleOptions) error
}
type LifecycleFetcher ¶ added in v0.2.0
type ProxyConfig ¶ added in v0.2.0
type RebaseOptions ¶ added in v0.2.0
type RunOptions ¶ added in v0.2.0
type RunOptions struct {
AppPath string // defaults to current working directory
Builder string // defaults to default builder on the client config
RunImage string // defaults to the best mirror from the builder image
Env map[string]string
NoPull bool
ClearCache bool
Buildpacks []string
Ports []string
}
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
pack
command
|
|
|
mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
|
internal
|
|
|
logging
Package logging implements the logger for the pack CLI.
|
Package logging implements the logger for the pack CLI. |
|
mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
|
Package logging defines the minimal interface that loggers must support to be used by pack.
|
Package logging defines the minimal interface that loggers must support to be used by pack. |
|
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
Click to show internal directories.
Click to hide internal directories.