pack

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 24, 2018 License: Apache-2.0 Imports: 28 Imported by: 0

README

pack - Buildpack CLI Build Status

pack is a tool to create runnable images from applications using buildpacks.

For information on buildpacks: buildpacks.io

Example Usage

Currently we recommend using the development detect image

./pack build <REPONAME> [-p <PATH to APP>] --detect-image packsdev/v3:detect

The above will create images on your local daemon. If you wish to create images on a docker registry, use the --publish flag.

./pack build myorg/myapp -p fixtures/node_app --detect-image packsdev/v3:detect --publish

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(appDir, buildImage, runImage, repoName string, publish bool) error

Types

type BuildFlags added in v0.0.2

type BuildFlags struct {
	AppDir   string
	Builder  string
	RunImage string
	RepoName string
	Publish  bool
	NoPull   bool
	// Below are set by init
	Cli             *docker.Docker
	WorkspaceVolume string
	CacheVolume     string
	Stdout          io.Writer
	Stderr          io.Writer
	Log             *log.Logger
	FS              FS
}

func (*BuildFlags) Analyze added in v0.0.3

func (b *BuildFlags) Analyze() error

func (*BuildFlags) Build added in v0.0.3

func (b *BuildFlags) Build() error

func (*BuildFlags) Close added in v0.0.3

func (b *BuildFlags) Close() error

func (*BuildFlags) Detect added in v0.0.3

func (b *BuildFlags) Detect() (*lifecycle.BuildpackGroup, error)

func (*BuildFlags) Export added in v0.0.3

func (b *BuildFlags) Export(group *lifecycle.BuildpackGroup) error

func (*BuildFlags) Init added in v0.0.3

func (b *BuildFlags) Init() error

func (*BuildFlags) Run added in v0.0.2

func (b *BuildFlags) Run() error

type BuilderConfig added in v0.0.3

type BuilderConfig struct {
	RepoName   string
	Buildpacks []Buildpack                `toml:"buildpacks"`
	Groups     []lifecycle.BuildpackGroup `toml:"groups"`
	Stack      Stack
	NoPull     bool
}

type BuilderFactory added in v0.0.2

type BuilderFactory struct {
	FS FS
}

func (*BuilderFactory) Create added in v0.0.2

func (f *BuilderFactory) Create(config BuilderConfig) error

type Buildpack added in v0.0.2

type Buildpack struct {
	ID  string
	URI string
}

type FS added in v0.0.3

type FS interface {
	CreateTGZFile(tarFile, srcDir, tarDir string, uid, gid int) error
	CreateTarReader(srcDir, tarDir string, uid, gid int) (io.Reader, chan error)
	Untar(r io.Reader, dest string) error
	CreateSingleFileTar(path, txt string) (io.Reader, error)
}

type Stack added in v0.0.2

type Stack struct {
	BuildImage v1.Image
}

func DefaultStack added in v0.0.3

func DefaultStack(noPull bool) (Stack, error)

Directories

Path Synopsis
cmd
pack command

Jump to