pack

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 17, 2018 License: Apache-2.0 Imports: 25 Imported by: 0

README

pack - Buildpack CLI Build Status

pack is a tool to create runnable images from applications using buildpacks.

For information on buildpacks: buildpacks.io

Example Usage

Currently we recommend using the development detect image

./pack build <REPONAME> [-p <PATH to APP>] --detect-image packsdev/v3:detect

The above will create images on your local daemon. If you wish to create images on a docker registry, use the --publish flag.

./pack build myorg/myapp -p fixtures/node_app --detect-image packsdev/v3:detect --publish

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(appDir, buildImage, runImage, repoName string, publish bool) error

Types

type BuildFlags added in v0.0.2

type BuildFlags struct {
	AppDir   string
	Builder  string
	RunImage string
	RepoName string
	Publish  bool
}

func (*BuildFlags) Run added in v0.0.2

func (b *BuildFlags) Run() error

type Builder added in v0.0.2

type Builder struct {
	Buildpacks []Buildpack                `toml:"buildpacks"`
	Groups     []lifecycle.BuildpackGroup `toml:"groups"`
}

type BuilderFactory added in v0.0.2

type BuilderFactory struct {
	DefaultStack Stack
}

func (*BuilderFactory) Create added in v0.0.2

func (f *BuilderFactory) Create(flags CreateBuilderFlags) error

type Buildpack added in v0.0.2

type Buildpack struct {
	ID  string
	URI string
}

type CreateBuilderFlags added in v0.0.2

type CreateBuilderFlags struct {
	RepoName        string
	BuilderTomlPath string
}

type Stack added in v0.0.2

type Stack struct {
	ID         string
	BuildImage string
	RunImage   string
}

Directories

Path Synopsis
cmd
pack command

Jump to