Documentation
¶
Index ¶
- func AddHelpFlag(cmd *cobra.Command, commandName string)
- func Build(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command
- func CreateBuilder(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command
- func InspectBuilder(logger *logging.Logger, cfg *config.Config, inspector BuilderInspector) *cobra.Command
- func IsSoftError(err error) bool
- func Rebase(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command
- func Run(logger *logging.Logger, fetcher pack.Fetcher) *cobra.Command
- func SetDefaultBuilder(logger *logging.Logger) *cobra.Command
- func SetRunImagesMirrors(logger *logging.Logger) *cobra.Command
- func Version(logger *logging.Logger, version string) *cobra.Command
- type BuilderInspector
- type SoftError
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddHelpFlag ¶
TODO: Check if most recent cobra version fixed bug in help strings. It was not always capitalizing the first letter in the help string. If it's fixed, we can remove this.
func CreateBuilder ¶
func InspectBuilder ¶
func IsSoftError ¶
Types ¶
type BuilderInspector ¶
type BuilderInspector interface {
InspectBuilder(string, bool) (*pack.BuilderInfo, error)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.